# Mantle
Generate insights from private network trace data on-prem.

## Getting started
* Create a virtual env using Anaconda, Miniconda and create an environment `python=3.12`
* Install mantle and it's dependencies using `pip install mantle-client`
* Launch Jupyter notebook and 
  * import mantle as `from mantle_client.client import Client`
  * connect to servers `client = Client(<url>, <username>, <password>)`
